/****************************************************************************
** Meta object code from reading C++ file 'Activities.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../kactivitymanagerd-6.6.90/src/service/Activities.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'Activities.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN10ActivitiesE_t {};
} // unnamed namespace

template <> constexpr inline auto Activities::qt_create_metaobjectdata<qt_meta_tag_ZN10ActivitiesE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Activities",
        "D-Bus Interface",
        "org.kde.ActivityManager.Activities",
        "CurrentActivityChanged",
        "",
        "activity",
        "ActivityAdded",
        "ActivityRemoved",
        "ActivityNameChanged",
        "name",
        "ActivityDescriptionChanged",
        "description",
        "ActivityIconChanged",
        "icon",
        "ActivityChanged",
        "CurrentActivity",
        "ListActivities",
        "ActivityName",
        "ActivityDescription",
        "ActivityIcon",
        "ListActivitiesWithInformation",
        "ActivityInfoList",
        "ActivityInformation",
        "ActivityInfo",
        "SetCurrentActivity",
        "PreviousActivity",
        "NextActivity",
        "AddActivity",
        "RemoveActivity",
        "SetActivityName",
        "SetActivityDescription",
        "SetActivityIcon"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'CurrentActivityChanged'
        QtMocHelpers::SignalData<void(const QString &)>(3, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 5 },
        }}),
        // Signal 'ActivityAdded'
        QtMocHelpers::SignalData<void(const QString &)>(6, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 5 },
        }}),
        // Signal 'ActivityRemoved'
        QtMocHelpers::SignalData<void(const QString &)>(7, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 5 },
        }}),
        // Signal 'ActivityNameChanged'
        QtMocHelpers::SignalData<void(const QString &, const QString &)>(8, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 5 }, { QMetaType::QString, 9 },
        }}),
        // Signal 'ActivityDescriptionChanged'
        QtMocHelpers::SignalData<void(const QString &, const QString &)>(10, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 5 }, { QMetaType::QString, 11 },
        }}),
        // Signal 'ActivityIconChanged'
        QtMocHelpers::SignalData<void(const QString &, const QString &)>(12, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 5 }, { QMetaType::QString, 13 },
        }}),
        // Signal 'ActivityChanged'
        QtMocHelpers::SignalData<void(const QString &)>(14, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 5 },
        }}),
        // Slot 'CurrentActivity'
        QtMocHelpers::SlotData<QString() const>(15, 4, QMC::AccessPublic, QMetaType::QString),
        // Slot 'ListActivities'
        QtMocHelpers::SlotData<QStringList() const>(16, 4, QMC::AccessPublic, QMetaType::QStringList),
        // Slot 'ActivityName'
        QtMocHelpers::SlotData<QString(const QString &) const>(17, 4, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::QString, 5 },
        }}),
        // Slot 'ActivityDescription'
        QtMocHelpers::SlotData<QString(const QString &) const>(18, 4, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::QString, 5 },
        }}),
        // Slot 'ActivityIcon'
        QtMocHelpers::SlotData<QString(const QString &) const>(19, 4, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::QString, 5 },
        }}),
        // Slot 'ListActivitiesWithInformation'
        QtMocHelpers::SlotData<ActivityInfoList() const>(20, 4, QMC::AccessPublic, 0x80000000 | 21),
        // Slot 'ActivityInformation'
        QtMocHelpers::SlotData<ActivityInfo(const QString &) const>(22, 4, QMC::AccessPublic, 0x80000000 | 23, {{
            { QMetaType::QString, 5 },
        }}),
        // Slot 'SetCurrentActivity'
        QtMocHelpers::SlotData<bool(const QString &)>(24, 4, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 5 },
        }}),
        // Slot 'PreviousActivity'
        QtMocHelpers::SlotData<bool()>(25, 4, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'NextActivity'
        QtMocHelpers::SlotData<bool()>(26, 4, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'AddActivity'
        QtMocHelpers::SlotData<QString(const QString &)>(27, 4, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::QString, 9 },
        }}),
        // Slot 'RemoveActivity'
        QtMocHelpers::SlotData<void(const QString &)>(28, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 5 },
        }}),
        // Slot 'SetActivityName'
        QtMocHelpers::SlotData<void(const QString &, const QString &)>(29, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 5 }, { QMetaType::QString, 9 },
        }}),
        // Slot 'SetActivityDescription'
        QtMocHelpers::SlotData<void(const QString &, const QString &)>(30, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 5 }, { QMetaType::QString, 11 },
        }}),
        // Slot 'SetActivityIcon'
        QtMocHelpers::SlotData<void(const QString &, const QString &)>(31, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 5 }, { QMetaType::QString, 13 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'CurrentActivity'
        QtMocHelpers::PropertyData<QString>(15, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable, 0),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<Activities, qt_meta_tag_ZN10ActivitiesE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject Activities::staticMetaObject = { {
    QMetaObject::SuperData::link<Module::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10ActivitiesE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10ActivitiesE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN10ActivitiesE_t>.metaTypes,
    nullptr
} };

void Activities::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Activities *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->CurrentActivityChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 1: _t->ActivityAdded((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 2: _t->ActivityRemoved((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 3: _t->ActivityNameChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 4: _t->ActivityDescriptionChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 5: _t->ActivityIconChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 6: _t->ActivityChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 7: { QString _r = _t->CurrentActivity();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 8: { QStringList _r = _t->ListActivities();
            if (_a[0]) *reinterpret_cast<QStringList*>(_a[0]) = std::move(_r); }  break;
        case 9: { QString _r = _t->ActivityName((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 10: { QString _r = _t->ActivityDescription((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 11: { QString _r = _t->ActivityIcon((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 12: { ActivityInfoList _r = _t->ListActivitiesWithInformation();
            if (_a[0]) *reinterpret_cast<ActivityInfoList*>(_a[0]) = std::move(_r); }  break;
        case 13: { ActivityInfo _r = _t->ActivityInformation((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<ActivityInfo*>(_a[0]) = std::move(_r); }  break;
        case 14: { bool _r = _t->SetCurrentActivity((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 15: { bool _r = _t->PreviousActivity();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 16: { bool _r = _t->NextActivity();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 17: { QString _r = _t->AddActivity((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 18: _t->RemoveActivity((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 19: _t->SetActivityName((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 20: _t->SetActivityDescription((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 21: _t->SetActivityIcon((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (Activities::*)(const QString & )>(_a, &Activities::CurrentActivityChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (Activities::*)(const QString & )>(_a, &Activities::ActivityAdded, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (Activities::*)(const QString & )>(_a, &Activities::ActivityRemoved, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (Activities::*)(const QString & , const QString & )>(_a, &Activities::ActivityNameChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (Activities::*)(const QString & , const QString & )>(_a, &Activities::ActivityDescriptionChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (Activities::*)(const QString & , const QString & )>(_a, &Activities::ActivityIconChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (Activities::*)(const QString & )>(_a, &Activities::ActivityChanged, 6))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->CurrentActivity(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->SetCurrentActivity(*reinterpret_cast<QString*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *Activities::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Activities::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10ActivitiesE_t>.strings))
        return static_cast<void*>(this);
    return Module::qt_metacast(_clname);
}

int Activities::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = Module::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 22)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 22;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 22)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 22;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    return _id;
}

// SIGNAL 0
void Activities::CurrentActivityChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void Activities::ActivityAdded(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void Activities::ActivityRemoved(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void Activities::ActivityNameChanged(const QString & _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1, _t2);
}

// SIGNAL 4
void Activities::ActivityDescriptionChanged(const QString & _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1, _t2);
}

// SIGNAL 5
void Activities::ActivityIconChanged(const QString & _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1, _t2);
}

// SIGNAL 6
void Activities::ActivityChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}
QT_WARNING_POP
