/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.kde.ActivityManager.Activities.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * This file may have been hand-edited. Look for HAND-EDIT comments
 * before re-generating it.
 */

#ifndef ACTIVITIESADAPTOR_H
#define ACTIVITIESADAPTOR_H

#include <QtCore/QObject>
#include <QtDBus/QtDBus>
#include "Activities.h"
#include <QtCore/qcontainerfwd.h>

/*
 * Adaptor class for interface org.kde.ActivityManager.Activities
 */
class ActivitiesAdaptor: public QDBusAbstractAdaptor
{
    Q_OBJECT
    Q_CLASSINFO("D-Bus Interface", "org.kde.ActivityManager.Activities")
    Q_CLASSINFO("D-Bus Introspection", ""
"  <interface name=\"org.kde.ActivityManager.Activities\">\n"
"    <method name=\"CurrentActivity\">\n"
"      <arg direction=\"out\" type=\"s\"/>\n"
"    </method>\n"
"    <method name=\"SetCurrentActivity\">\n"
"      <arg direction=\"out\" type=\"b\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"activity\"/>\n"
"    </method>\n"
"    <method name=\"PreviousActivity\">\n"
"      <arg direction=\"out\" type=\"b\"/>\n"
"    </method>\n"
"    <method name=\"NextActivity\">\n"
"      <arg direction=\"out\" type=\"b\"/>\n"
"    </method>\n"
"    <method name=\"AddActivity\">\n"
"      <arg direction=\"out\" type=\"s\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"name\"/>\n"
"    </method>\n"
"    <method name=\"RemoveActivity\">\n"
"      <arg direction=\"in\" type=\"s\" name=\"activity\"/>\n"
"    </method>\n"
"    <method name=\"ListActivities\">\n"
"      <arg direction=\"out\" type=\"as\"/>\n"
"    </method>\n"
"    <method name=\"ListActivitiesWithInformation\">\n"
"      <arg direction=\"out\" type=\"a(ssssii)\"/>\n"
"      <annotation value=\"ActivityInfoList\" name=\"org.qtproject.QtDBus.QtTypeName.Out0\"/>\n"
"      <annotation value=\"ActivityInfoList\" name=\"org.qtproject.QtDBus.QtTypeName.Out0\"/>\n"
"    </method>\n"
"    <method name=\"ActivityInformation\">\n"
"      <arg direction=\"out\" type=\"(ssssii)\"/>\n"
"      <annotation value=\"ActivityInfo\" name=\"org.qtproject.QtDBus.QtTypeName.Out0\"/>\n"
"      <annotation value=\"ActivityInfo\" name=\"org.qtproject.QtDBus.QtTypeName.Out0\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"activity\"/>\n"
"    </method>\n"
"    <method name=\"ActivityName\">\n"
"      <arg direction=\"out\" type=\"s\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"activity\"/>\n"
"    </method>\n"
"    <method name=\"SetActivityName\">\n"
"      <arg direction=\"in\" type=\"s\" name=\"activity\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"name\"/>\n"
"    </method>\n"
"    <method name=\"ActivityDescription\">\n"
"      <arg direction=\"out\" type=\"s\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"activity\"/>\n"
"    </method>\n"
"    <method name=\"SetActivityDescription\">\n"
"      <arg direction=\"in\" type=\"s\" name=\"activity\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"description\"/>\n"
"    </method>\n"
"    <method name=\"ActivityIcon\">\n"
"      <arg direction=\"out\" type=\"s\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"activity\"/>\n"
"    </method>\n"
"    <method name=\"SetActivityIcon\">\n"
"      <arg direction=\"in\" type=\"s\" name=\"activity\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"icon\"/>\n"
"    </method>\n"
"    <signal name=\"CurrentActivityChanged\">\n"
"      <arg direction=\"out\" type=\"s\" name=\"activity\"/>\n"
"    </signal>\n"
"    <signal name=\"ActivityAdded\">\n"
"      <arg direction=\"out\" type=\"s\" name=\"activity\"/>\n"
"    </signal>\n"
"    <signal name=\"ActivityStarted\">\n"
"      <arg direction=\"out\" type=\"s\" name=\"activity\"/>\n"
"    </signal>\n"
"    <signal name=\"ActivityStopped\">\n"
"      <arg direction=\"out\" type=\"s\" name=\"activity\"/>\n"
"    </signal>\n"
"    <signal name=\"ActivityRemoved\">\n"
"      <arg direction=\"out\" type=\"s\" name=\"activity\"/>\n"
"    </signal>\n"
"    <signal name=\"ActivityChanged\">\n"
"      <arg direction=\"out\" type=\"s\" name=\"activity\"/>\n"
"    </signal>\n"
"    <signal name=\"ActivityNameChanged\">\n"
"      <arg direction=\"out\" type=\"s\" name=\"activity\"/>\n"
"      <arg direction=\"out\" type=\"s\" name=\"name\"/>\n"
"    </signal>\n"
"    <signal name=\"ActivityDescriptionChanged\">\n"
"      <arg direction=\"out\" type=\"s\" name=\"activity\"/>\n"
"      <arg direction=\"out\" type=\"s\" name=\"description\"/>\n"
"    </signal>\n"
"    <signal name=\"ActivityIconChanged\">\n"
"      <arg direction=\"out\" type=\"s\" name=\"activity\"/>\n"
"      <arg direction=\"out\" type=\"s\" name=\"icon\"/>\n"
"    </signal>\n"
"    <signal name=\"ActivitiesSortOrderChanged\">\n"
"      <arg direction=\"out\" type=\"a(ssssii)\"/>\n"
"      <annotation value=\"ActivityInfoList\" name=\"org.qtproject.QtDBus.QtTypeName.Out0\"/>\n"
"      <annotation value=\"ActivityInfoList\" name=\"org.qtproject.QtDBus.QtTypeName.Out0\"/>\n"
"    </signal>\n"
"  </interface>\n"
        "")
public:
    ActivitiesAdaptor(Activities *parent);
    ~ActivitiesAdaptor() override;

    inline Activities *parent() const
    { return static_cast<Activities *>(QObject::parent()); }

public: // PROPERTIES
public Q_SLOTS: // METHODS
    QString ActivityDescription(const QString &activity);
    QString ActivityIcon(const QString &activity);
    ActivityInfo ActivityInformation(const QString &activity);
    QString ActivityName(const QString &activity);
    QString AddActivity(const QString &name);
    QString CurrentActivity();
    QStringList ListActivities();
    ActivityInfoList ListActivitiesWithInformation();
    bool NextActivity();
    bool PreviousActivity();
    void RemoveActivity(const QString &activity);
    void SetActivityDescription(const QString &activity, const QString &description);
    void SetActivityIcon(const QString &activity, const QString &icon);
    void SetActivityName(const QString &activity, const QString &name);
    bool SetCurrentActivity(const QString &activity);
Q_SIGNALS: // SIGNALS
    void ActivitiesSortOrderChanged(ActivityInfoList in0);
    void ActivityAdded(const QString &activity);
    void ActivityChanged(const QString &activity);
    void ActivityDescriptionChanged(const QString &activity, const QString &description);
    void ActivityIconChanged(const QString &activity, const QString &icon);
    void ActivityNameChanged(const QString &activity, const QString &name);
    void ActivityRemoved(const QString &activity);
    void ActivityStarted(const QString &activity);
    void ActivityStopped(const QString &activity);
    void CurrentActivityChanged(const QString &activity);
};

#endif
