/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.kde.ActivityManager.ResourcesLinking.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#include "resourcelinkingadaptor.h"
#include <QtCore/QMetaObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>

/*
 * Implementation of adaptor class ResourcesLinkingAdaptor
 */

ResourcesLinkingAdaptor::ResourcesLinkingAdaptor(ResourceLinking *parent)
    : QDBusAbstractAdaptor(parent)
{
    // constructor
    setAutoRelaySignals(true);
}

ResourcesLinkingAdaptor::~ResourcesLinkingAdaptor()
{
    // destructor
}

bool ResourcesLinkingAdaptor::IsResourceLinkedToActivity(const QString &agent, const QString &resource)
{
    // handle method call org.kde.ActivityManager.ResourcesLinking.IsResourceLinkedToActivity
    return parent()->IsResourceLinkedToActivity(agent, resource);
}

bool ResourcesLinkingAdaptor::IsResourceLinkedToActivity(const QString &agent, const QString &resource, const QString &activity)
{
    // handle method call org.kde.ActivityManager.ResourcesLinking.IsResourceLinkedToActivity
    return parent()->IsResourceLinkedToActivity(agent, resource, activity);
}

void ResourcesLinkingAdaptor::LinkResourceToActivity(const QString &agent, const QString &resource)
{
    // handle method call org.kde.ActivityManager.ResourcesLinking.LinkResourceToActivity
    parent()->LinkResourceToActivity(agent, resource);
}

void ResourcesLinkingAdaptor::LinkResourceToActivity(const QString &agent, const QString &resource, const QString &activity)
{
    // handle method call org.kde.ActivityManager.ResourcesLinking.LinkResourceToActivity
    parent()->LinkResourceToActivity(agent, resource, activity);
}

void ResourcesLinkingAdaptor::UnlinkResourceFromActivity(const QString &agent, const QString &resource)
{
    // handle method call org.kde.ActivityManager.ResourcesLinking.UnlinkResourceFromActivity
    parent()->UnlinkResourceFromActivity(agent, resource);
}

void ResourcesLinkingAdaptor::UnlinkResourceFromActivity(const QString &agent, const QString &resource, const QString &activity)
{
    // handle method call org.kde.ActivityManager.ResourcesLinking.UnlinkResourceFromActivity
    parent()->UnlinkResourceFromActivity(agent, resource, activity);
}


#include "moc_resourcelinkingadaptor.cpp"
