/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.kde.ActivityManager.Features.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#include "featuresadaptor.h"
#include <QtCore/QMetaObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>

/*
 * Implementation of adaptor class FeaturesAdaptor
 */

FeaturesAdaptor::FeaturesAdaptor(Features *parent)
    : QDBusAbstractAdaptor(parent)
{
    // constructor
    setAutoRelaySignals(true);
}

FeaturesAdaptor::~FeaturesAdaptor()
{
    // destructor
}

QDBusVariant FeaturesAdaptor::GetValue(const QString &property)
{
    // handle method call org.kde.ActivityManager.Features.GetValue
    return parent()->GetValue(property);
}

bool FeaturesAdaptor::IsFeatureOperational(const QString &feature)
{
    // handle method call org.kde.ActivityManager.Features.IsFeatureOperational
    return parent()->IsFeatureOperational(feature);
}

QStringList FeaturesAdaptor::ListFeatures(const QString &module)
{
    // handle method call org.kde.ActivityManager.Features.ListFeatures
    return parent()->ListFeatures(module);
}

void FeaturesAdaptor::SetValue(const QString &property, const QDBusVariant &value)
{
    // handle method call org.kde.ActivityManager.Features.SetValue
    parent()->SetValue(property, value);
}


#include "moc_featuresadaptor.cpp"
