/****************************************************************************
** Meta object code from reading C++ file 'resourcelinkingadaptor.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "resourcelinkingadaptor.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'resourcelinkingadaptor.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN23ResourcesLinkingAdaptorE_t {};
} // unnamed namespace

template <> constexpr inline auto ResourcesLinkingAdaptor::qt_create_metaobjectdata<qt_meta_tag_ZN23ResourcesLinkingAdaptorE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ResourcesLinkingAdaptor",
        "D-Bus Interface",
        "org.kde.ActivityManager.ResourcesLinking",
        "D-Bus Introspection",
        "  <interface name=\"org.kde.ActivityManager.ResourcesLinking\">\n "
        "   <method name=\"LinkResourceToActivity\">\n      <arg direction="
        "\"in\" type=\"s\" name=\"agent\"/>\n      <arg direction=\"in\" ty"
        "pe=\"s\" name=\"resource\"/>\n      <arg direction=\"in\" type=\"s"
        "\" name=\"activity\"/>\n    </method>\n    <method name=\"LinkReso"
        "urceToActivity\">\n      <arg direction=\"in\" type=\"s\" name=\"a"
        "gent\"/>\n      <arg direction=\"in\" type=\"s\" name=\"resource\""
        "/>\n    </method>\n    <method name=\"UnlinkResourceFromActivity\""
        ">\n      <arg direction=\"in\" type=\"s\" name=\"agent\"/>\n      "
        "<arg direction=\"in\" type=\"s\" name=\"resource\"/>\n      <arg d"
        "irection=\"in\" type=\"s\" name=\"activity\"/>\n    </method>\n   "
        " <method name=\"UnlinkResourceFromActivity\">\n      <arg directio"
        "n=\"in\" type=\"s\" name=\"agent\"/>\n      <arg direction=\"in\" "
        "type=\"s\" name=\"resource\"/>\n    </method>\n    <method name=\""
        "IsResourceLinkedToActivity\">\n      <arg direction=\"in\" type=\""
        "s\" name=\"agent\"/>\n      <arg direction=\"in\" type=\"s\" name="
        "\"resource\"/>\n      <arg direction=\"in\" type=\"s\" name=\"acti"
        "vity\"/>\n      <arg direction=\"out\" type=\"b\"/>\n    </method>"
        "\n    <method name=\"IsResourceLinkedToActivity\">\n      <arg dir"
        "ection=\"in\" type=\"s\" name=\"agent\"/>\n      <arg direction=\""
        "in\" type=\"s\" name=\"resource\"/>\n      <arg direction=\"out\" "
        "type=\"b\"/>\n    </method>\n    <signal name=\"ResourceLinkedToAc"
        "tivity\">\n      <arg direction=\"out\" type=\"s\" name=\"agent\"/"
        ">\n      <arg direction=\"out\" type=\"s\" name=\"resource\"/>\n  "
        "    <arg direction=\"out\" type=\"s\" name=\"activity\"/>\n    </s"
        "ignal>\n    <signal name=\"ResourceUnlinkedFromActivity\">\n      "
        "<arg direction=\"out\" type=\"s\" name=\"agent\"/>\n      <arg dir"
        "ection=\"out\" type=\"s\" name=\"resource\"/>\n      <arg directio"
        "n=\"out\" type=\"s\" name=\"activity\"/>\n    </signal>\n  </inter"
        "face>\n",
        "ResourceLinkedToActivity",
        "",
        "agent",
        "resource",
        "activity",
        "ResourceUnlinkedFromActivity",
        "IsResourceLinkedToActivity",
        "LinkResourceToActivity",
        "UnlinkResourceFromActivity"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'ResourceLinkedToActivity'
        QtMocHelpers::SignalData<void(const QString &, const QString &, const QString &)>(5, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 }, { QMetaType::QString, 8 }, { QMetaType::QString, 9 },
        }}),
        // Signal 'ResourceUnlinkedFromActivity'
        QtMocHelpers::SignalData<void(const QString &, const QString &, const QString &)>(10, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 }, { QMetaType::QString, 8 }, { QMetaType::QString, 9 },
        }}),
        // Slot 'IsResourceLinkedToActivity'
        QtMocHelpers::SlotData<bool(const QString &, const QString &)>(11, 6, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 7 }, { QMetaType::QString, 8 },
        }}),
        // Slot 'IsResourceLinkedToActivity'
        QtMocHelpers::SlotData<bool(const QString &, const QString &, const QString &)>(11, 6, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 7 }, { QMetaType::QString, 8 }, { QMetaType::QString, 9 },
        }}),
        // Slot 'LinkResourceToActivity'
        QtMocHelpers::SlotData<void(const QString &, const QString &)>(12, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 }, { QMetaType::QString, 8 },
        }}),
        // Slot 'LinkResourceToActivity'
        QtMocHelpers::SlotData<void(const QString &, const QString &, const QString &)>(12, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 }, { QMetaType::QString, 8 }, { QMetaType::QString, 9 },
        }}),
        // Slot 'UnlinkResourceFromActivity'
        QtMocHelpers::SlotData<void(const QString &, const QString &)>(13, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 }, { QMetaType::QString, 8 },
        }}),
        // Slot 'UnlinkResourceFromActivity'
        QtMocHelpers::SlotData<void(const QString &, const QString &, const QString &)>(13, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 }, { QMetaType::QString, 8 }, { QMetaType::QString, 9 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<ResourcesLinkingAdaptor, qt_meta_tag_ZN23ResourcesLinkingAdaptorE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject ResourcesLinkingAdaptor::staticMetaObject = { {
    QMetaObject::SuperData::link<QDBusAbstractAdaptor::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN23ResourcesLinkingAdaptorE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN23ResourcesLinkingAdaptorE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN23ResourcesLinkingAdaptorE_t>.metaTypes,
    nullptr
} };

void ResourcesLinkingAdaptor::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ResourcesLinkingAdaptor *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->ResourceLinkedToActivity((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 1: _t->ResourceUnlinkedFromActivity((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 2: { bool _r = _t->IsResourceLinkedToActivity((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 3: { bool _r = _t->IsResourceLinkedToActivity((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 4: _t->LinkResourceToActivity((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 5: _t->LinkResourceToActivity((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 6: _t->UnlinkResourceFromActivity((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 7: _t->UnlinkResourceFromActivity((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (ResourcesLinkingAdaptor::*)(const QString & , const QString & , const QString & )>(_a, &ResourcesLinkingAdaptor::ResourceLinkedToActivity, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (ResourcesLinkingAdaptor::*)(const QString & , const QString & , const QString & )>(_a, &ResourcesLinkingAdaptor::ResourceUnlinkedFromActivity, 1))
            return;
    }
}

const QMetaObject *ResourcesLinkingAdaptor::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ResourcesLinkingAdaptor::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN23ResourcesLinkingAdaptorE_t>.strings))
        return static_cast<void*>(this);
    return QDBusAbstractAdaptor::qt_metacast(_clname);
}

int ResourcesLinkingAdaptor::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDBusAbstractAdaptor::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 8)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 8)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 8;
    }
    return _id;
}

// SIGNAL 0
void ResourcesLinkingAdaptor::ResourceLinkedToActivity(const QString & _t1, const QString & _t2, const QString & _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2, _t3);
}

// SIGNAL 1
void ResourcesLinkingAdaptor::ResourceUnlinkedFromActivity(const QString & _t1, const QString & _t2, const QString & _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2, _t3);
}
QT_WARNING_POP
