/****************************************************************************
** Meta object code from reading C++ file 'StatsPlugin.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../../kactivitymanagerd-6.6.90/src/service/plugins/sqlite/StatsPlugin.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'StatsPlugin.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN11StatsPluginE_t {};
} // unnamed namespace

template <> constexpr inline auto StatsPlugin::qt_create_metaobjectdata<qt_meta_tag_ZN11StatsPluginE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "StatsPlugin",
        "ResourceScoreUpdated",
        "",
        "activity",
        "client",
        "resource",
        "score",
        "lastUpdate",
        "firstUpdate",
        "ResourceScoreDeleted",
        "RecentStatsDeleted",
        "count",
        "what",
        "EarlierStatsDeleted",
        "months",
        "DeleteRecentStats",
        "DeleteEarlierStats",
        "DeleteStatsForResource",
        "addEvents",
        "EventList",
        "events",
        "loadConfiguration",
        "openResourceEvent",
        "usedActivity",
        "initiatingAgent",
        "targettedResource",
        "start",
        "end",
        "closeResourceEvent",
        "saveResourceTitle",
        "uri",
        "title",
        "autoTitle",
        "saveResourceMimetype",
        "mimetype",
        "autoMimetype",
        "insertResourceInfo",
        "detectResourceInfo",
        "deleteOldEvents"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'ResourceScoreUpdated'
        QtMocHelpers::SignalData<void(const QString &, const QString &, const QString &, double, uint, uint)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 }, { QMetaType::QString, 4 }, { QMetaType::QString, 5 }, { QMetaType::Double, 6 },
            { QMetaType::UInt, 7 }, { QMetaType::UInt, 8 },
        }}),
        // Signal 'ResourceScoreDeleted'
        QtMocHelpers::SignalData<void(const QString &, const QString &, const QString &)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 }, { QMetaType::QString, 4 }, { QMetaType::QString, 5 },
        }}),
        // Signal 'RecentStatsDeleted'
        QtMocHelpers::SignalData<void(const QString &, int, const QString &)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 }, { QMetaType::Int, 11 }, { QMetaType::QString, 12 },
        }}),
        // Signal 'EarlierStatsDeleted'
        QtMocHelpers::SignalData<void(const QString &, int)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 }, { QMetaType::Int, 14 },
        }}),
        // Slot 'DeleteRecentStats'
        QtMocHelpers::SlotData<void(const QString &, int, const QString &)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 }, { QMetaType::Int, 11 }, { QMetaType::QString, 12 },
        }}),
        // Slot 'DeleteEarlierStats'
        QtMocHelpers::SlotData<void(const QString &, int)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 }, { QMetaType::Int, 14 },
        }}),
        // Slot 'DeleteStatsForResource'
        QtMocHelpers::SlotData<void(const QString &, const QString &, const QString &)>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 }, { QMetaType::QString, 4 }, { QMetaType::QString, 5 },
        }}),
        // Slot 'addEvents'
        QtMocHelpers::SlotData<void(const EventList &)>(18, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 19, 20 },
        }}),
        // Slot 'loadConfiguration'
        QtMocHelpers::SlotData<void()>(21, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'openResourceEvent'
        QtMocHelpers::SlotData<void(const QString &, const QString &, const QString &, const QDateTime &, const QDateTime &)>(22, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 23 }, { QMetaType::QString, 24 }, { QMetaType::QString, 25 }, { QMetaType::QDateTime, 26 },
            { QMetaType::QDateTime, 27 },
        }}),
        // Slot 'openResourceEvent'
        QtMocHelpers::SlotData<void(const QString &, const QString &, const QString &, const QDateTime &)>(22, 2, QMC::AccessPrivate | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::QString, 23 }, { QMetaType::QString, 24 }, { QMetaType::QString, 25 }, { QMetaType::QDateTime, 26 },
        }}),
        // Slot 'closeResourceEvent'
        QtMocHelpers::SlotData<void(const QString &, const QString &, const QString &, const QDateTime &)>(28, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 23 }, { QMetaType::QString, 24 }, { QMetaType::QString, 25 }, { QMetaType::QDateTime, 27 },
        }}),
        // Slot 'saveResourceTitle'
        QtMocHelpers::SlotData<void(const QString &, const QString &, bool)>(29, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 30 }, { QMetaType::QString, 31 }, { QMetaType::Bool, 32 },
        }}),
        // Slot 'saveResourceTitle'
        QtMocHelpers::SlotData<void(const QString &, const QString &)>(29, 2, QMC::AccessPrivate | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::QString, 30 }, { QMetaType::QString, 31 },
        }}),
        // Slot 'saveResourceMimetype'
        QtMocHelpers::SlotData<void(const QString &, const QString &, bool)>(33, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 30 }, { QMetaType::QString, 34 }, { QMetaType::Bool, 35 },
        }}),
        // Slot 'saveResourceMimetype'
        QtMocHelpers::SlotData<void(const QString &, const QString &)>(33, 2, QMC::AccessPrivate | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::QString, 30 }, { QMetaType::QString, 34 },
        }}),
        // Slot 'insertResourceInfo'
        QtMocHelpers::SlotData<bool(const QString &)>(36, 2, QMC::AccessPrivate, QMetaType::Bool, {{
            { QMetaType::QString, 30 },
        }}),
        // Slot 'detectResourceInfo'
        QtMocHelpers::SlotData<void(const QString &)>(37, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 30 },
        }}),
        // Slot 'deleteOldEvents'
        QtMocHelpers::SlotData<void()>(38, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<StatsPlugin, qt_meta_tag_ZN11StatsPluginE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject StatsPlugin::staticMetaObject = { {
    QMetaObject::SuperData::link<Plugin::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11StatsPluginE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11StatsPluginE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN11StatsPluginE_t>.metaTypes,
    nullptr
} };

void StatsPlugin::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<StatsPlugin *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->ResourceScoreUpdated((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[6]))); break;
        case 1: _t->ResourceScoreDeleted((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 2: _t->RecentStatsDeleted((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 3: _t->EarlierStatsDeleted((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 4: _t->DeleteRecentStats((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 5: _t->DeleteEarlierStats((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 6: _t->DeleteStatsForResource((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 7: _t->addEvents((*reinterpret_cast<std::add_pointer_t<EventList>>(_a[1]))); break;
        case 8: _t->loadConfiguration(); break;
        case 9: _t->openResourceEvent((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QDateTime>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QDateTime>>(_a[5]))); break;
        case 10: _t->openResourceEvent((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QDateTime>>(_a[4]))); break;
        case 11: _t->closeResourceEvent((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QDateTime>>(_a[4]))); break;
        case 12: _t->saveResourceTitle((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3]))); break;
        case 13: _t->saveResourceTitle((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 14: _t->saveResourceMimetype((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3]))); break;
        case 15: _t->saveResourceMimetype((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 16: { bool _r = _t->insertResourceInfo((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 17: _t->detectResourceInfo((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 18: _t->deleteOldEvents(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 7:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< EventList >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (StatsPlugin::*)(const QString & , const QString & , const QString & , double , uint , uint )>(_a, &StatsPlugin::ResourceScoreUpdated, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (StatsPlugin::*)(const QString & , const QString & , const QString & )>(_a, &StatsPlugin::ResourceScoreDeleted, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (StatsPlugin::*)(const QString & , int , const QString & )>(_a, &StatsPlugin::RecentStatsDeleted, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (StatsPlugin::*)(const QString & , int )>(_a, &StatsPlugin::EarlierStatsDeleted, 3))
            return;
    }
}

const QMetaObject *StatsPlugin::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *StatsPlugin::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11StatsPluginE_t>.strings))
        return static_cast<void*>(this);
    return Plugin::qt_metacast(_clname);
}

int StatsPlugin::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = Plugin::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 19)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 19;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 19)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 19;
    }
    return _id;
}

// SIGNAL 0
void StatsPlugin::ResourceScoreUpdated(const QString & _t1, const QString & _t2, const QString & _t3, double _t4, uint _t5, uint _t6)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2, _t3, _t4, _t5, _t6);
}

// SIGNAL 1
void StatsPlugin::ResourceScoreDeleted(const QString & _t1, const QString & _t2, const QString & _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2, _t3);
}

// SIGNAL 2
void StatsPlugin::RecentStatsDeleted(const QString & _t1, int _t2, const QString & _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1, _t2, _t3);
}

// SIGNAL 3
void StatsPlugin::EarlierStatsDeleted(const QString & _t1, int _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1, _t2);
}
QT_WARNING_POP
