/****************************************************************************
** Meta object code from reading C++ file 'Resources.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../kactivitymanagerd-6.6.90/src/service/Resources.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'Resources.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN9ResourcesE_t {};
} // unnamed namespace

template <> constexpr inline auto Resources::qt_create_metaobjectdata<qt_meta_tag_ZN9ResourcesE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Resources",
        "D-Bus Interface",
        "org.kde.ActivityManager.Resources",
        "RegisteredResourceEvent",
        "",
        "Event",
        "event",
        "ProcessedResourceEvents",
        "EventList",
        "events",
        "RegisteredResourceMimetype",
        "uri",
        "mimetype",
        "RegisteredResourceTitle",
        "title",
        "RegisterResourceEvent",
        "application",
        "windowId",
        "RegisterResourceMimetype",
        "RegisterResourceTitle"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'RegisteredResourceEvent'
        QtMocHelpers::SignalData<void(const Event &)>(3, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 6 },
        }}),
        // Signal 'ProcessedResourceEvents'
        QtMocHelpers::SignalData<void(const EventList &)>(7, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 8, 9 },
        }}),
        // Signal 'RegisteredResourceMimetype'
        QtMocHelpers::SignalData<void(const QString &, const QString &)>(10, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 11 }, { QMetaType::QString, 12 },
        }}),
        // Signal 'RegisteredResourceTitle'
        QtMocHelpers::SignalData<void(const QString &, const QString &)>(13, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 11 }, { QMetaType::QString, 14 },
        }}),
        // Slot 'RegisterResourceEvent'
        QtMocHelpers::SlotData<void(const QString &, uint, const QString &, uint)>(15, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 16 }, { QMetaType::UInt, 17 }, { QMetaType::QString, 11 }, { QMetaType::UInt, 6 },
        }}),
        // Slot 'RegisterResourceMimetype'
        QtMocHelpers::SlotData<void(const QString &, const QString &)>(18, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 11 }, { QMetaType::QString, 12 },
        }}),
        // Slot 'RegisterResourceTitle'
        QtMocHelpers::SlotData<void(const QString &, const QString &)>(19, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 11 }, { QMetaType::QString, 14 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<Resources, qt_meta_tag_ZN9ResourcesE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject Resources::staticMetaObject = { {
    QMetaObject::SuperData::link<Module::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9ResourcesE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9ResourcesE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN9ResourcesE_t>.metaTypes,
    nullptr
} };

void Resources::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Resources *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->RegisteredResourceEvent((*reinterpret_cast<std::add_pointer_t<Event>>(_a[1]))); break;
        case 1: _t->ProcessedResourceEvents((*reinterpret_cast<std::add_pointer_t<EventList>>(_a[1]))); break;
        case 2: _t->RegisteredResourceMimetype((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 3: _t->RegisteredResourceTitle((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 4: _t->RegisterResourceEvent((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[4]))); break;
        case 5: _t->RegisterResourceMimetype((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 6: _t->RegisterResourceTitle((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Event >(); break;
            }
            break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< EventList >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (Resources::*)(const Event & )>(_a, &Resources::RegisteredResourceEvent, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (Resources::*)(const EventList & )>(_a, &Resources::ProcessedResourceEvents, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (Resources::*)(const QString & , const QString & )>(_a, &Resources::RegisteredResourceMimetype, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (Resources::*)(const QString & , const QString & )>(_a, &Resources::RegisteredResourceTitle, 3))
            return;
    }
}

const QMetaObject *Resources::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Resources::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9ResourcesE_t>.strings))
        return static_cast<void*>(this);
    return Module::qt_metacast(_clname);
}

int Resources::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = Module::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 7)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 7)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    }
    return _id;
}

// SIGNAL 0
void Resources::RegisteredResourceEvent(const Event & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void Resources::ProcessedResourceEvents(const EventList & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void Resources::RegisteredResourceMimetype(const QString & _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1, _t2);
}

// SIGNAL 3
void Resources::RegisteredResourceTitle(const QString & _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1, _t2);
}
QT_WARNING_POP
