/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.kde.ActivityManager.Resources.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#include "resourcesadaptor.h"
#include <QtCore/QMetaObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>

/*
 * Implementation of adaptor class ResourcesAdaptor
 */

ResourcesAdaptor::ResourcesAdaptor(Resources *parent)
    : QDBusAbstractAdaptor(parent)
{
    // constructor
    setAutoRelaySignals(true);
}

ResourcesAdaptor::~ResourcesAdaptor()
{
    // destructor
}

void ResourcesAdaptor::RegisterResourceEvent(const QString &application, uint windowId, const QString &uri, uint event)
{
    // handle method call org.kde.ActivityManager.Resources.RegisterResourceEvent
    parent()->RegisterResourceEvent(application, windowId, uri, event);
}

void ResourcesAdaptor::RegisterResourceMimetype(const QString &uri, const QString &mimetype)
{
    // handle method call org.kde.ActivityManager.Resources.RegisterResourceMimetype
    parent()->RegisterResourceMimetype(uri, mimetype);
}

void ResourcesAdaptor::RegisterResourceTitle(const QString &uri, const QString &title)
{
    // handle method call org.kde.ActivityManager.Resources.RegisterResourceTitle
    parent()->RegisterResourceTitle(uri, title);
}


#include "moc_resourcesadaptor.cpp"
