/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.kde.ActivityManager.Features.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * This file may have been hand-edited. Look for HAND-EDIT comments
 * before re-generating it.
 */

#ifndef FEATURESADAPTOR_H
#define FEATURESADAPTOR_H

#include <QtCore/QObject>
#include <QtDBus/QtDBus>
#include "Features.h"
#include <QtCore/qcontainerfwd.h>

/*
 * Adaptor class for interface org.kde.ActivityManager.Features
 */
class FeaturesAdaptor: public QDBusAbstractAdaptor
{
    Q_OBJECT
    Q_CLASSINFO("D-Bus Interface", "org.kde.ActivityManager.Features")
    Q_CLASSINFO("D-Bus Introspection", ""
"  <interface name=\"org.kde.ActivityManager.Features\">\n"
"    <method name=\"IsFeatureOperational\">\n"
"      <arg direction=\"out\" type=\"b\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"feature\"/>\n"
"    </method>\n"
"    <method name=\"ListFeatures\">\n"
"      <arg direction=\"out\" type=\"as\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"module\"/>\n"
"    </method>\n"
"    <method name=\"GetValue\">\n"
"      <arg direction=\"out\" type=\"v\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"property\"/>\n"
"    </method>\n"
"    <method name=\"SetValue\">\n"
"      <arg direction=\"in\" type=\"s\" name=\"property\"/>\n"
"      <arg direction=\"in\" type=\"v\" name=\"value\"/>\n"
"    </method>\n"
"  </interface>\n"
        "")
public:
    FeaturesAdaptor(Features *parent);
    ~FeaturesAdaptor() override;

    inline Features *parent() const
    { return static_cast<Features *>(QObject::parent()); }

public: // PROPERTIES
public Q_SLOTS: // METHODS
    QDBusVariant GetValue(const QString &property);
    bool IsFeatureOperational(const QString &feature);
    QStringList ListFeatures(const QString &module);
    void SetValue(const QString &property, const QDBusVariant &value);
Q_SIGNALS: // SIGNALS
};

#endif
