// This file was generated by ecm_qt_declare_logging_category(): DO NOT EDIT!

#include "DebugLibreOfficeEventSpy.h"


Q_LOGGING_CATEGORY(KAMD_LOG_PLUGIN_LIBREOFFICE_EVENTSPY, "org.kde.kactivities.plugin.libreoffice-eventspy", QtInfoMsg)

