/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.kde.ActivityManager.ResourcesLinking.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * This file may have been hand-edited. Look for HAND-EDIT comments
 * before re-generating it.
 */

#ifndef RESOURCELINKINGADAPTOR_H
#define RESOURCELINKINGADAPTOR_H

#include <QtCore/QObject>
#include <QtDBus/QtDBus>
#include "ResourceLinking.h"
#include <QtCore/qcontainerfwd.h>

/*
 * Adaptor class for interface org.kde.ActivityManager.ResourcesLinking
 */
class ResourcesLinkingAdaptor: public QDBusAbstractAdaptor
{
    Q_OBJECT
    Q_CLASSINFO("D-Bus Interface", "org.kde.ActivityManager.ResourcesLinking")
    Q_CLASSINFO("D-Bus Introspection", ""
"  <interface name=\"org.kde.ActivityManager.ResourcesLinking\">\n"
"    <method name=\"LinkResourceToActivity\">\n"
"      <arg direction=\"in\" type=\"s\" name=\"agent\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"resource\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"activity\"/>\n"
"    </method>\n"
"    <method name=\"LinkResourceToActivity\">\n"
"      <arg direction=\"in\" type=\"s\" name=\"agent\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"resource\"/>\n"
"    </method>\n"
"    <method name=\"UnlinkResourceFromActivity\">\n"
"      <arg direction=\"in\" type=\"s\" name=\"agent\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"resource\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"activity\"/>\n"
"    </method>\n"
"    <method name=\"UnlinkResourceFromActivity\">\n"
"      <arg direction=\"in\" type=\"s\" name=\"agent\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"resource\"/>\n"
"    </method>\n"
"    <method name=\"IsResourceLinkedToActivity\">\n"
"      <arg direction=\"in\" type=\"s\" name=\"agent\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"resource\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"activity\"/>\n"
"      <arg direction=\"out\" type=\"b\"/>\n"
"    </method>\n"
"    <method name=\"IsResourceLinkedToActivity\">\n"
"      <arg direction=\"in\" type=\"s\" name=\"agent\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"resource\"/>\n"
"      <arg direction=\"out\" type=\"b\"/>\n"
"    </method>\n"
"    <signal name=\"ResourceLinkedToActivity\">\n"
"      <arg direction=\"out\" type=\"s\" name=\"agent\"/>\n"
"      <arg direction=\"out\" type=\"s\" name=\"resource\"/>\n"
"      <arg direction=\"out\" type=\"s\" name=\"activity\"/>\n"
"    </signal>\n"
"    <signal name=\"ResourceUnlinkedFromActivity\">\n"
"      <arg direction=\"out\" type=\"s\" name=\"agent\"/>\n"
"      <arg direction=\"out\" type=\"s\" name=\"resource\"/>\n"
"      <arg direction=\"out\" type=\"s\" name=\"activity\"/>\n"
"    </signal>\n"
"  </interface>\n"
        "")
public:
    ResourcesLinkingAdaptor(ResourceLinking *parent);
    ~ResourcesLinkingAdaptor() override;

    inline ResourceLinking *parent() const
    { return static_cast<ResourceLinking *>(QObject::parent()); }

public: // PROPERTIES
public Q_SLOTS: // METHODS
    bool IsResourceLinkedToActivity(const QString &agent, const QString &resource);
    bool IsResourceLinkedToActivity(const QString &agent, const QString &resource, const QString &activity);
    void LinkResourceToActivity(const QString &agent, const QString &resource);
    void LinkResourceToActivity(const QString &agent, const QString &resource, const QString &activity);
    void UnlinkResourceFromActivity(const QString &agent, const QString &resource);
    void UnlinkResourceFromActivity(const QString &agent, const QString &resource, const QString &activity);
Q_SIGNALS: // SIGNALS
    void ResourceLinkedToActivity(const QString &agent, const QString &resource, const QString &activity);
    void ResourceUnlinkedFromActivity(const QString &agent, const QString &resource, const QString &activity);
};

#endif
