/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.kde.ActivityManager.ResourcesScoring.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#include "resourcescoringadaptor.h"
#include <QtCore/QMetaObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>

/*
 * Implementation of adaptor class ResourcesScoringAdaptor
 */

ResourcesScoringAdaptor::ResourcesScoringAdaptor(StatsPlugin *parent)
    : QDBusAbstractAdaptor(parent)
{
    // constructor
    setAutoRelaySignals(true);
}

ResourcesScoringAdaptor::~ResourcesScoringAdaptor()
{
    // destructor
}

void ResourcesScoringAdaptor::DeleteEarlierStats(const QString &activity, int months)
{
    // handle method call org.kde.ActivityManager.ResourcesScoring.DeleteEarlierStats
    parent()->DeleteEarlierStats(activity, months);
}

void ResourcesScoringAdaptor::DeleteRecentStats(const QString &activity, int count, const QString &what)
{
    // handle method call org.kde.ActivityManager.ResourcesScoring.DeleteRecentStats
    parent()->DeleteRecentStats(activity, count, what);
}

void ResourcesScoringAdaptor::DeleteStatsForResource(const QString &activity, const QString &client, const QString &resource)
{
    // handle method call org.kde.ActivityManager.ResourcesScoring.DeleteStatsForResource
    parent()->DeleteStatsForResource(activity, client, resource);
}


#include "moc_resourcescoringadaptor.cpp"
