/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.kde.ActivityManager.ResourcesScoring.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * This file may have been hand-edited. Look for HAND-EDIT comments
 * before re-generating it.
 */

#ifndef RESOURCESCORINGADAPTOR_H
#define RESOURCESCORINGADAPTOR_H

#include <QtCore/QObject>
#include <QtDBus/QtDBus>
#include "StatsPlugin.h"
#include <QtCore/qcontainerfwd.h>

/*
 * Adaptor class for interface org.kde.ActivityManager.ResourcesScoring
 */
class ResourcesScoringAdaptor: public QDBusAbstractAdaptor
{
    Q_OBJECT
    Q_CLASSINFO("D-Bus Interface", "org.kde.ActivityManager.ResourcesScoring")
    Q_CLASSINFO("D-Bus Introspection", ""
"  <interface name=\"org.kde.ActivityManager.ResourcesScoring\">\n"
"    <signal name=\"ResourceScoreUpdated\">\n"
"      <arg direction=\"out\" type=\"s\" name=\"activity\"/>\n"
"      <arg direction=\"out\" type=\"s\" name=\"client\"/>\n"
"      <arg direction=\"out\" type=\"s\" name=\"resource\"/>\n"
"      <arg direction=\"out\" type=\"d\" name=\"score\"/>\n"
"      <arg direction=\"out\" type=\"u\" name=\"lastUpdate\"/>\n"
"      <arg direction=\"out\" type=\"u\" name=\"firstUpdate\"/>\n"
"    </signal>\n"
"    <signal name=\"ResourceScoreDeleted\">\n"
"      <arg direction=\"out\" type=\"s\" name=\"activity\"/>\n"
"      <arg direction=\"out\" type=\"s\" name=\"client\"/>\n"
"      <arg direction=\"out\" type=\"s\" name=\"resource\"/>\n"
"    </signal>\n"
"    <signal name=\"RecentStatsDeleted\">\n"
"      <arg direction=\"out\" type=\"s\" name=\"activity\"/>\n"
"      <arg direction=\"out\" type=\"i\" name=\"count\"/>\n"
"      <arg direction=\"out\" type=\"s\" name=\"what\"/>\n"
"    </signal>\n"
"    <signal name=\"EarlierStatsDeleted\">\n"
"      <arg direction=\"out\" type=\"s\" name=\"activity\"/>\n"
"      <arg direction=\"out\" type=\"i\" name=\"months\"/>\n"
"    </signal>\n"
"    <method name=\"DeleteStatsForResource\">\n"
"      <arg direction=\"in\" type=\"s\" name=\"activity\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"client\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"resource\"/>\n"
"    </method>\n"
"    <method name=\"DeleteRecentStats\">\n"
"      <arg direction=\"in\" type=\"s\" name=\"activity\"/>\n"
"      <arg direction=\"in\" type=\"i\" name=\"count\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"what\"/>\n"
"    </method>\n"
"    <method name=\"DeleteEarlierStats\">\n"
"      <arg direction=\"in\" type=\"s\" name=\"activity\"/>\n"
"      <arg direction=\"in\" type=\"i\" name=\"months\"/>\n"
"    </method>\n"
"  </interface>\n"
        "")
public:
    ResourcesScoringAdaptor(StatsPlugin *parent);
    ~ResourcesScoringAdaptor() override;

    inline StatsPlugin *parent() const
    { return static_cast<StatsPlugin *>(QObject::parent()); }

public: // PROPERTIES
public Q_SLOTS: // METHODS
    void DeleteEarlierStats(const QString &activity, int months);
    void DeleteRecentStats(const QString &activity, int count, const QString &what);
    void DeleteStatsForResource(const QString &activity, const QString &client, const QString &resource);
Q_SIGNALS: // SIGNALS
    void EarlierStatsDeleted(const QString &activity, int months);
    void RecentStatsDeleted(const QString &activity, int count, const QString &what);
    void ResourceScoreDeleted(const QString &activity, const QString &client, const QString &resource);
    void ResourceScoreUpdated(const QString &activity, const QString &client, const QString &resource, double score, uint lastUpdate, uint firstUpdate);
};

#endif
