/****************************************************************************
** Meta object code from reading C++ file 'resourcescoringadaptor.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "resourcescoringadaptor.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'resourcescoringadaptor.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN23ResourcesScoringAdaptorE_t {};
} // unnamed namespace

template <> constexpr inline auto ResourcesScoringAdaptor::qt_create_metaobjectdata<qt_meta_tag_ZN23ResourcesScoringAdaptorE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ResourcesScoringAdaptor",
        "D-Bus Interface",
        "org.kde.ActivityManager.ResourcesScoring",
        "D-Bus Introspection",
        "  <interface name=\"org.kde.ActivityManager.ResourcesScoring\">\n "
        "   <signal name=\"ResourceScoreUpdated\">\n      <arg direction=\""
        "out\" type=\"s\" name=\"activity\"/>\n      <arg direction=\"out\""
        " type=\"s\" name=\"client\"/>\n      <arg direction=\"out\" type=\""
        "s\" name=\"resource\"/>\n      <arg direction=\"out\" type=\"d\" n"
        "ame=\"score\"/>\n      <arg direction=\"out\" type=\"u\" name=\"la"
        "stUpdate\"/>\n      <arg direction=\"out\" type=\"u\" name=\"first"
        "Update\"/>\n    </signal>\n    <signal name=\"ResourceScoreDeleted"
        "\">\n      <arg direction=\"out\" type=\"s\" name=\"activity\"/>\n"
        "      <arg direction=\"out\" type=\"s\" name=\"client\"/>\n      <"
        "arg direction=\"out\" type=\"s\" name=\"resource\"/>\n    </signal"
        ">\n    <signal name=\"RecentStatsDeleted\">\n      <arg direction="
        "\"out\" type=\"s\" name=\"activity\"/>\n      <arg direction=\"out"
        "\" type=\"i\" name=\"count\"/>\n      <arg direction=\"out\" type="
        "\"s\" name=\"what\"/>\n    </signal>\n    <signal name=\"EarlierSt"
        "atsDeleted\">\n      <arg direction=\"out\" type=\"s\" name=\"acti"
        "vity\"/>\n      <arg direction=\"out\" type=\"i\" name=\"months\"/"
        ">\n    </signal>\n    <method name=\"DeleteStatsForResource\">\n  "
        "    <arg direction=\"in\" type=\"s\" name=\"activity\"/>\n      <a"
        "rg direction=\"in\" type=\"s\" name=\"client\"/>\n      <arg direc"
        "tion=\"in\" type=\"s\" name=\"resource\"/>\n    </method>\n    <me"
        "thod name=\"DeleteRecentStats\">\n      <arg direction=\"in\" type"
        "=\"s\" name=\"activity\"/>\n      <arg direction=\"in\" type=\"i\""
        " name=\"count\"/>\n      <arg direction=\"in\" type=\"s\" name=\"w"
        "hat\"/>\n    </method>\n    <method name=\"DeleteEarlierStats\">\n"
        "      <arg direction=\"in\" type=\"s\" name=\"activity\"/>\n      "
        "<arg direction=\"in\" type=\"i\" name=\"months\"/>\n    </method>\n"
        "  </interface>\n",
        "EarlierStatsDeleted",
        "",
        "activity",
        "months",
        "RecentStatsDeleted",
        "count",
        "what",
        "ResourceScoreDeleted",
        "client",
        "resource",
        "ResourceScoreUpdated",
        "score",
        "lastUpdate",
        "firstUpdate",
        "DeleteEarlierStats",
        "DeleteRecentStats",
        "DeleteStatsForResource"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'EarlierStatsDeleted'
        QtMocHelpers::SignalData<void(const QString &, int)>(5, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 }, { QMetaType::Int, 8 },
        }}),
        // Signal 'RecentStatsDeleted'
        QtMocHelpers::SignalData<void(const QString &, int, const QString &)>(9, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 }, { QMetaType::Int, 10 }, { QMetaType::QString, 11 },
        }}),
        // Signal 'ResourceScoreDeleted'
        QtMocHelpers::SignalData<void(const QString &, const QString &, const QString &)>(12, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 }, { QMetaType::QString, 13 }, { QMetaType::QString, 14 },
        }}),
        // Signal 'ResourceScoreUpdated'
        QtMocHelpers::SignalData<void(const QString &, const QString &, const QString &, double, uint, uint)>(15, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 }, { QMetaType::QString, 13 }, { QMetaType::QString, 14 }, { QMetaType::Double, 16 },
            { QMetaType::UInt, 17 }, { QMetaType::UInt, 18 },
        }}),
        // Slot 'DeleteEarlierStats'
        QtMocHelpers::SlotData<void(const QString &, int)>(19, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 }, { QMetaType::Int, 8 },
        }}),
        // Slot 'DeleteRecentStats'
        QtMocHelpers::SlotData<void(const QString &, int, const QString &)>(20, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 }, { QMetaType::Int, 10 }, { QMetaType::QString, 11 },
        }}),
        // Slot 'DeleteStatsForResource'
        QtMocHelpers::SlotData<void(const QString &, const QString &, const QString &)>(21, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 }, { QMetaType::QString, 13 }, { QMetaType::QString, 14 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<ResourcesScoringAdaptor, qt_meta_tag_ZN23ResourcesScoringAdaptorE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject ResourcesScoringAdaptor::staticMetaObject = { {
    QMetaObject::SuperData::link<QDBusAbstractAdaptor::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN23ResourcesScoringAdaptorE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN23ResourcesScoringAdaptorE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN23ResourcesScoringAdaptorE_t>.metaTypes,
    nullptr
} };

void ResourcesScoringAdaptor::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ResourcesScoringAdaptor *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->EarlierStatsDeleted((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 1: _t->RecentStatsDeleted((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 2: _t->ResourceScoreDeleted((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 3: _t->ResourceScoreUpdated((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[6]))); break;
        case 4: _t->DeleteEarlierStats((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 5: _t->DeleteRecentStats((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 6: _t->DeleteStatsForResource((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (ResourcesScoringAdaptor::*)(const QString & , int )>(_a, &ResourcesScoringAdaptor::EarlierStatsDeleted, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (ResourcesScoringAdaptor::*)(const QString & , int , const QString & )>(_a, &ResourcesScoringAdaptor::RecentStatsDeleted, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (ResourcesScoringAdaptor::*)(const QString & , const QString & , const QString & )>(_a, &ResourcesScoringAdaptor::ResourceScoreDeleted, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (ResourcesScoringAdaptor::*)(const QString & , const QString & , const QString & , double , uint , uint )>(_a, &ResourcesScoringAdaptor::ResourceScoreUpdated, 3))
            return;
    }
}

const QMetaObject *ResourcesScoringAdaptor::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ResourcesScoringAdaptor::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN23ResourcesScoringAdaptorE_t>.strings))
        return static_cast<void*>(this);
    return QDBusAbstractAdaptor::qt_metacast(_clname);
}

int ResourcesScoringAdaptor::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDBusAbstractAdaptor::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 7)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 7)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 7;
    }
    return _id;
}

// SIGNAL 0
void ResourcesScoringAdaptor::EarlierStatsDeleted(const QString & _t1, int _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2);
}

// SIGNAL 1
void ResourcesScoringAdaptor::RecentStatsDeleted(const QString & _t1, int _t2, const QString & _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2, _t3);
}

// SIGNAL 2
void ResourcesScoringAdaptor::ResourceScoreDeleted(const QString & _t1, const QString & _t2, const QString & _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1, _t2, _t3);
}

// SIGNAL 3
void ResourcesScoringAdaptor::ResourceScoreUpdated(const QString & _t1, const QString & _t2, const QString & _t3, double _t4, uint _t5, uint _t6)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1, _t2, _t3, _t4, _t5, _t6);
}
QT_WARNING_POP
