/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.kde.ActivityManager.Activities.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#include "activitiesadaptor.h"
#include <QtCore/QMetaObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>

/*
 * Implementation of adaptor class ActivitiesAdaptor
 */

ActivitiesAdaptor::ActivitiesAdaptor(Activities *parent)
    : QDBusAbstractAdaptor(parent)
{
    // constructor
    setAutoRelaySignals(true);
}

ActivitiesAdaptor::~ActivitiesAdaptor()
{
    // destructor
}

QString ActivitiesAdaptor::ActivityDescription(const QString &activity)
{
    // handle method call org.kde.ActivityManager.Activities.ActivityDescription
    return parent()->ActivityDescription(activity);
}

QString ActivitiesAdaptor::ActivityIcon(const QString &activity)
{
    // handle method call org.kde.ActivityManager.Activities.ActivityIcon
    return parent()->ActivityIcon(activity);
}

ActivityInfo ActivitiesAdaptor::ActivityInformation(const QString &activity)
{
    // handle method call org.kde.ActivityManager.Activities.ActivityInformation
    return parent()->ActivityInformation(activity);
}

QString ActivitiesAdaptor::ActivityName(const QString &activity)
{
    // handle method call org.kde.ActivityManager.Activities.ActivityName
    return parent()->ActivityName(activity);
}

QString ActivitiesAdaptor::AddActivity(const QString &name)
{
    // handle method call org.kde.ActivityManager.Activities.AddActivity
    return parent()->AddActivity(name);
}

QString ActivitiesAdaptor::CurrentActivity()
{
    // handle method call org.kde.ActivityManager.Activities.CurrentActivity
    return parent()->CurrentActivity();
}

QStringList ActivitiesAdaptor::ListActivities()
{
    // handle method call org.kde.ActivityManager.Activities.ListActivities
    return parent()->ListActivities();
}

ActivityInfoList ActivitiesAdaptor::ListActivitiesWithInformation()
{
    // handle method call org.kde.ActivityManager.Activities.ListActivitiesWithInformation
    return parent()->ListActivitiesWithInformation();
}

bool ActivitiesAdaptor::NextActivity()
{
    // handle method call org.kde.ActivityManager.Activities.NextActivity
    return parent()->NextActivity();
}

bool ActivitiesAdaptor::PreviousActivity()
{
    // handle method call org.kde.ActivityManager.Activities.PreviousActivity
    return parent()->PreviousActivity();
}

void ActivitiesAdaptor::RemoveActivity(const QString &activity)
{
    // handle method call org.kde.ActivityManager.Activities.RemoveActivity
    parent()->RemoveActivity(activity);
}

void ActivitiesAdaptor::SetActivityDescription(const QString &activity, const QString &description)
{
    // handle method call org.kde.ActivityManager.Activities.SetActivityDescription
    parent()->SetActivityDescription(activity, description);
}

void ActivitiesAdaptor::SetActivityIcon(const QString &activity, const QString &icon)
{
    // handle method call org.kde.ActivityManager.Activities.SetActivityIcon
    parent()->SetActivityIcon(activity, icon);
}

void ActivitiesAdaptor::SetActivityName(const QString &activity, const QString &name)
{
    // handle method call org.kde.ActivityManager.Activities.SetActivityName
    parent()->SetActivityName(activity, name);
}

bool ActivitiesAdaptor::SetCurrentActivity(const QString &activity)
{
    // handle method call org.kde.ActivityManager.Activities.SetCurrentActivity
    return parent()->SetCurrentActivity(activity);
}


#include "moc_activitiesadaptor.cpp"
