/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.kde.ActivityManager.Resources.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * This file may have been hand-edited. Look for HAND-EDIT comments
 * before re-generating it.
 */

#ifndef RESOURCESADAPTOR_H
#define RESOURCESADAPTOR_H

#include <QtCore/QObject>
#include <QtDBus/QtDBus>
#include "Resources.h"
#include <QtCore/qcontainerfwd.h>

/*
 * Adaptor class for interface org.kde.ActivityManager.Resources
 */
class ResourcesAdaptor: public QDBusAbstractAdaptor
{
    Q_OBJECT
    Q_CLASSINFO("D-Bus Interface", "org.kde.ActivityManager.Resources")
    Q_CLASSINFO("D-Bus Introspection", ""
"  <interface name=\"org.kde.ActivityManager.Resources\">\n"
"    <method name=\"RegisterResourceEvent\">\n"
"      <arg direction=\"in\" type=\"s\" name=\"application\"/>\n"
"      <arg direction=\"in\" type=\"u\" name=\"windowId\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"uri\"/>\n"
"      <arg direction=\"in\" type=\"u\" name=\"event\"/>\n"
"    </method>\n"
"    <method name=\"RegisterResourceMimetype\">\n"
"      <arg direction=\"in\" type=\"s\" name=\"uri\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"mimetype\"/>\n"
"    </method>\n"
"    <method name=\"RegisterResourceTitle\">\n"
"      <arg direction=\"in\" type=\"s\" name=\"uri\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"title\"/>\n"
"    </method>\n"
"  </interface>\n"
        "")
public:
    ResourcesAdaptor(Resources *parent);
    ~ResourcesAdaptor() override;

    inline Resources *parent() const
    { return static_cast<Resources *>(QObject::parent()); }

public: // PROPERTIES
public Q_SLOTS: // METHODS
    void RegisterResourceEvent(const QString &application, uint windowId, const QString &uri, uint event);
    void RegisterResourceMimetype(const QString &uri, const QString &mimetype);
    void RegisterResourceTitle(const QString &uri, const QString &title);
Q_SIGNALS: // SIGNALS
};

#endif
