/****************************************************************************
** Meta object code from reading C++ file 'activitiesadaptor.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "activitiesadaptor.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'activitiesadaptor.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN17ActivitiesAdaptorE_t {};
} // unnamed namespace

template <> constexpr inline auto ActivitiesAdaptor::qt_create_metaobjectdata<qt_meta_tag_ZN17ActivitiesAdaptorE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ActivitiesAdaptor",
        "D-Bus Interface",
        "org.kde.ActivityManager.Activities",
        "D-Bus Introspection",
        "  <interface name=\"org.kde.ActivityManager.Activities\">\n    <me"
        "thod name=\"CurrentActivity\">\n      <arg direction=\"out\" type="
        "\"s\"/>\n    </method>\n    <method name=\"SetCurrentActivity\">\n"
        "      <arg direction=\"out\" type=\"b\"/>\n      <arg direction=\""
        "in\" type=\"s\" name=\"activity\"/>\n    </method>\n    <method na"
        "me=\"PreviousActivity\">\n      <arg direction=\"out\" type=\"b\"/"
        ">\n    </method>\n    <method name=\"NextActivity\">\n      <arg d"
        "irection=\"out\" type=\"b\"/>\n    </method>\n    <method name=\"A"
        "ddActivity\">\n      <arg direction=\"out\" type=\"s\"/>\n      <a"
        "rg direction=\"in\" type=\"s\" name=\"name\"/>\n    </method>\n   "
        " <method name=\"RemoveActivity\">\n      <arg direction=\"in\" typ"
        "e=\"s\" name=\"activity\"/>\n    </method>\n    <method name=\"Lis"
        "tActivities\">\n      <arg direction=\"out\" type=\"as\"/>\n    </"
        "method>\n    <method name=\"ListActivitiesWithInformation\">\n    "
        "  <arg direction=\"out\" type=\"a(ssssii)\"/>\n      <annotation v"
        "alue=\"ActivityInfoList\" name=\"org.qtproject.QtDBus.QtTypeName.O"
        "ut0\"/>\n      <annotation value=\"ActivityInfoList\" name=\"org.q"
        "tproject.QtDBus.QtTypeName.Out0\"/>\n    </method>\n    <method na"
        "me=\"ActivityInformation\">\n      <arg direction=\"out\" type=\"("
        "ssssii)\"/>\n      <annotation value=\"ActivityInfo\" name=\"org.q"
        "tproject.QtDBus.QtTypeName.Out0\"/>\n      <annotation value=\"Act"
        "ivityInfo\" name=\"org.qtproject.QtDBus.QtTypeName.Out0\"/>\n     "
        " <arg direction=\"in\" type=\"s\" name=\"activity\"/>\n    </metho"
        "d>\n    <method name=\"ActivityName\">\n      <arg direction=\"out"
        "\" type=\"s\"/>\n      <arg direction=\"in\" type=\"s\" name=\"act"
        "ivity\"/>\n    </method>\n    <method name=\"SetActivityName\">\n "
        "     <arg direction=\"in\" type=\"s\" name=\"activity\"/>\n      <"
        "arg direction=\"in\" type=\"s\" name=\"name\"/>\n    </method>\n  "
        "  <method name=\"ActivityDescription\">\n      <arg direction=\"ou"
        "t\" type=\"s\"/>\n      <arg direction=\"in\" type=\"s\" name=\"ac"
        "tivity\"/>\n    </method>\n    <method name=\"SetActivityDescripti"
        "on\">\n      <arg direction=\"in\" type=\"s\" name=\"activity\"/>\n"
        "      <arg direction=\"in\" type=\"s\" name=\"description\"/>\n   "
        " </method>\n    <method name=\"ActivityIcon\">\n      <arg directi"
        "on=\"out\" type=\"s\"/>\n      <arg direction=\"in\" type=\"s\" na"
        "me=\"activity\"/>\n    </method>\n    <method name=\"SetActivityIc"
        "on\">\n      <arg direction=\"in\" type=\"s\" name=\"activity\"/>\n"
        "      <arg direction=\"in\" type=\"s\" name=\"icon\"/>\n    </meth"
        "od>\n    <signal name=\"CurrentActivityChanged\">\n      <arg dire"
        "ction=\"out\" type=\"s\" name=\"activity\"/>\n    </signal>\n    <"
        "signal name=\"ActivityAdded\">\n      <arg direction=\"out\" type="
        "\"s\" name=\"activity\"/>\n    </signal>\n    <signal name=\"Activ"
        "ityStarted\">\n      <arg direction=\"out\" type=\"s\" name=\"acti"
        "vity\"/>\n    </signal>\n    <signal name=\"ActivityStopped\">\n  "
        "    <arg direction=\"out\" type=\"s\" name=\"activity\"/>\n    </s"
        "ignal>\n    <signal name=\"ActivityRemoved\">\n      <arg directio"
        "n=\"out\" type=\"s\" name=\"activity\"/>\n    </signal>\n    <sign"
        "al name=\"ActivityChanged\">\n      <arg direction=\"out\" type=\""
        "s\" name=\"activity\"/>\n    </signal>\n    <signal name=\"Activit"
        "yNameChanged\">\n      <arg direction=\"out\" type=\"s\" name=\"ac"
        "tivity\"/>\n      <arg direction=\"out\" type=\"s\" name=\"name\"/"
        ">\n    </signal>\n    <signal name=\"ActivityDescriptionChanged\">"
        "\n      <arg direction=\"out\" type=\"s\" name=\"activity\"/>\n   "
        "   <arg direction=\"out\" type=\"s\" name=\"description\"/>\n    <"
        "/signal>\n    <signal name=\"ActivityIconChanged\">\n      <arg di"
        "rection=\"out\" type=\"s\" name=\"activity\"/>\n      <arg directi"
        "on=\"out\" type=\"s\" name=\"icon\"/>\n    </signal>\n    <signal "
        "name=\"ActivitiesSortOrderChanged\">\n      <arg direction=\"out\""
        " type=\"a(ssssii)\"/>\n      <annotation value=\"ActivityInfoList\""
        " name=\"org.qtproject.QtDBus.QtTypeName.Out0\"/>\n      <annotatio"
        "n value=\"ActivityInfoList\" name=\"org.qtproject.QtDBus.QtTypeNam"
        "e.Out0\"/>\n    </signal>\n  </interface>\n",
        "ActivitiesSortOrderChanged",
        "",
        "ActivityInfoList",
        "in0",
        "ActivityAdded",
        "activity",
        "ActivityChanged",
        "ActivityDescriptionChanged",
        "description",
        "ActivityIconChanged",
        "icon",
        "ActivityNameChanged",
        "name",
        "ActivityRemoved",
        "ActivityStarted",
        "ActivityStopped",
        "CurrentActivityChanged",
        "ActivityDescription",
        "ActivityIcon",
        "ActivityInformation",
        "ActivityInfo",
        "ActivityName",
        "AddActivity",
        "CurrentActivity",
        "ListActivities",
        "ListActivitiesWithInformation",
        "NextActivity",
        "PreviousActivity",
        "RemoveActivity",
        "SetActivityDescription",
        "SetActivityIcon",
        "SetActivityName",
        "SetCurrentActivity"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'ActivitiesSortOrderChanged'
        QtMocHelpers::SignalData<void(ActivityInfoList)>(5, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 8 },
        }}),
        // Signal 'ActivityAdded'
        QtMocHelpers::SignalData<void(const QString &)>(9, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 10 },
        }}),
        // Signal 'ActivityChanged'
        QtMocHelpers::SignalData<void(const QString &)>(11, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 10 },
        }}),
        // Signal 'ActivityDescriptionChanged'
        QtMocHelpers::SignalData<void(const QString &, const QString &)>(12, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 10 }, { QMetaType::QString, 13 },
        }}),
        // Signal 'ActivityIconChanged'
        QtMocHelpers::SignalData<void(const QString &, const QString &)>(14, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 10 }, { QMetaType::QString, 15 },
        }}),
        // Signal 'ActivityNameChanged'
        QtMocHelpers::SignalData<void(const QString &, const QString &)>(16, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 10 }, { QMetaType::QString, 17 },
        }}),
        // Signal 'ActivityRemoved'
        QtMocHelpers::SignalData<void(const QString &)>(18, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 10 },
        }}),
        // Signal 'ActivityStarted'
        QtMocHelpers::SignalData<void(const QString &)>(19, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 10 },
        }}),
        // Signal 'ActivityStopped'
        QtMocHelpers::SignalData<void(const QString &)>(20, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 10 },
        }}),
        // Signal 'CurrentActivityChanged'
        QtMocHelpers::SignalData<void(const QString &)>(21, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 10 },
        }}),
        // Slot 'ActivityDescription'
        QtMocHelpers::SlotData<QString(const QString &)>(22, 6, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::QString, 10 },
        }}),
        // Slot 'ActivityIcon'
        QtMocHelpers::SlotData<QString(const QString &)>(23, 6, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::QString, 10 },
        }}),
        // Slot 'ActivityInformation'
        QtMocHelpers::SlotData<ActivityInfo(const QString &)>(24, 6, QMC::AccessPublic, 0x80000000 | 25, {{
            { QMetaType::QString, 10 },
        }}),
        // Slot 'ActivityName'
        QtMocHelpers::SlotData<QString(const QString &)>(26, 6, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::QString, 10 },
        }}),
        // Slot 'AddActivity'
        QtMocHelpers::SlotData<QString(const QString &)>(27, 6, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::QString, 17 },
        }}),
        // Slot 'CurrentActivity'
        QtMocHelpers::SlotData<QString()>(28, 6, QMC::AccessPublic, QMetaType::QString),
        // Slot 'ListActivities'
        QtMocHelpers::SlotData<QStringList()>(29, 6, QMC::AccessPublic, QMetaType::QStringList),
        // Slot 'ListActivitiesWithInformation'
        QtMocHelpers::SlotData<ActivityInfoList()>(30, 6, QMC::AccessPublic, 0x80000000 | 7),
        // Slot 'NextActivity'
        QtMocHelpers::SlotData<bool()>(31, 6, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'PreviousActivity'
        QtMocHelpers::SlotData<bool()>(32, 6, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'RemoveActivity'
        QtMocHelpers::SlotData<void(const QString &)>(33, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 10 },
        }}),
        // Slot 'SetActivityDescription'
        QtMocHelpers::SlotData<void(const QString &, const QString &)>(34, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 10 }, { QMetaType::QString, 13 },
        }}),
        // Slot 'SetActivityIcon'
        QtMocHelpers::SlotData<void(const QString &, const QString &)>(35, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 10 }, { QMetaType::QString, 15 },
        }}),
        // Slot 'SetActivityName'
        QtMocHelpers::SlotData<void(const QString &, const QString &)>(36, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 10 }, { QMetaType::QString, 17 },
        }}),
        // Slot 'SetCurrentActivity'
        QtMocHelpers::SlotData<bool(const QString &)>(37, 6, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 10 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<ActivitiesAdaptor, qt_meta_tag_ZN17ActivitiesAdaptorE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject ActivitiesAdaptor::staticMetaObject = { {
    QMetaObject::SuperData::link<QDBusAbstractAdaptor::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17ActivitiesAdaptorE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17ActivitiesAdaptorE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN17ActivitiesAdaptorE_t>.metaTypes,
    nullptr
} };

void ActivitiesAdaptor::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ActivitiesAdaptor *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->ActivitiesSortOrderChanged((*reinterpret_cast<std::add_pointer_t<ActivityInfoList>>(_a[1]))); break;
        case 1: _t->ActivityAdded((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 2: _t->ActivityChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 3: _t->ActivityDescriptionChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 4: _t->ActivityIconChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 5: _t->ActivityNameChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 6: _t->ActivityRemoved((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 7: _t->ActivityStarted((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 8: _t->ActivityStopped((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 9: _t->CurrentActivityChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 10: { QString _r = _t->ActivityDescription((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 11: { QString _r = _t->ActivityIcon((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 12: { ActivityInfo _r = _t->ActivityInformation((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<ActivityInfo*>(_a[0]) = std::move(_r); }  break;
        case 13: { QString _r = _t->ActivityName((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 14: { QString _r = _t->AddActivity((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 15: { QString _r = _t->CurrentActivity();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 16: { QStringList _r = _t->ListActivities();
            if (_a[0]) *reinterpret_cast<QStringList*>(_a[0]) = std::move(_r); }  break;
        case 17: { ActivityInfoList _r = _t->ListActivitiesWithInformation();
            if (_a[0]) *reinterpret_cast<ActivityInfoList*>(_a[0]) = std::move(_r); }  break;
        case 18: { bool _r = _t->NextActivity();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 19: { bool _r = _t->PreviousActivity();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 20: _t->RemoveActivity((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 21: _t->SetActivityDescription((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 22: _t->SetActivityIcon((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 23: _t->SetActivityName((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 24: { bool _r = _t->SetCurrentActivity((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< ActivityInfoList >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (ActivitiesAdaptor::*)(ActivityInfoList )>(_a, &ActivitiesAdaptor::ActivitiesSortOrderChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (ActivitiesAdaptor::*)(const QString & )>(_a, &ActivitiesAdaptor::ActivityAdded, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (ActivitiesAdaptor::*)(const QString & )>(_a, &ActivitiesAdaptor::ActivityChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (ActivitiesAdaptor::*)(const QString & , const QString & )>(_a, &ActivitiesAdaptor::ActivityDescriptionChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (ActivitiesAdaptor::*)(const QString & , const QString & )>(_a, &ActivitiesAdaptor::ActivityIconChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (ActivitiesAdaptor::*)(const QString & , const QString & )>(_a, &ActivitiesAdaptor::ActivityNameChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (ActivitiesAdaptor::*)(const QString & )>(_a, &ActivitiesAdaptor::ActivityRemoved, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (ActivitiesAdaptor::*)(const QString & )>(_a, &ActivitiesAdaptor::ActivityStarted, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (ActivitiesAdaptor::*)(const QString & )>(_a, &ActivitiesAdaptor::ActivityStopped, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (ActivitiesAdaptor::*)(const QString & )>(_a, &ActivitiesAdaptor::CurrentActivityChanged, 9))
            return;
    }
}

const QMetaObject *ActivitiesAdaptor::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ActivitiesAdaptor::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17ActivitiesAdaptorE_t>.strings))
        return static_cast<void*>(this);
    return QDBusAbstractAdaptor::qt_metacast(_clname);
}

int ActivitiesAdaptor::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDBusAbstractAdaptor::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 25)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 25;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 25)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 25;
    }
    return _id;
}

// SIGNAL 0
void ActivitiesAdaptor::ActivitiesSortOrderChanged(ActivityInfoList _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void ActivitiesAdaptor::ActivityAdded(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void ActivitiesAdaptor::ActivityChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void ActivitiesAdaptor::ActivityDescriptionChanged(const QString & _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1, _t2);
}

// SIGNAL 4
void ActivitiesAdaptor::ActivityIconChanged(const QString & _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1, _t2);
}

// SIGNAL 5
void ActivitiesAdaptor::ActivityNameChanged(const QString & _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1, _t2);
}

// SIGNAL 6
void ActivitiesAdaptor::ActivityRemoved(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void ActivitiesAdaptor::ActivityStarted(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1);
}

// SIGNAL 8
void ActivitiesAdaptor::ActivityStopped(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1);
}

// SIGNAL 9
void ActivitiesAdaptor::CurrentActivityChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 9, nullptr, _t1);
}
QT_WARNING_POP
