// This file was generated by ecm_qt_declare_logging_category(): DO NOT EDIT!

#include "DebugPluginRecentlyUsedEventSpy.h"


Q_LOGGING_CATEGORY(KAMD_LOG_PLUGIN_RECENTLYUSED_EVENTSPY, "org.kde.kactivities.plugin.recentlyused-eventspy", QtInfoMsg)

